/**
 * Represents the parameters used for HMAC signature-based API request
 * authentication.
 *
 * Note: Not all API endpoints support this method of authentication.
 * Please refer to the specific API documentation to determine if HMAC
 * signature authentication is supported.
 *
 * For more information on signing requests, visit:
 * https://developer.vonage.com/en/getting-started/concepts/signing-messages
 */
export type AuthSignedParams = {
    /**
     * The API key used to authenticate requests. This value can be found in
     * your Vonage Developer Dashboard.
     */
    api_key: string;
    /**
     * The generated signature, used to verify the authenticity of the request.
     * It's typically generated by hashing the request parameters with a
     * secret key.
     */
    sig?: string;
    /**
     * The UNIX timestamp when the request is made. Utilized to prevent replay
     * attacks by making each signature unique to a specific time window.
     */
    timestamp?: string;
};
