"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MMSVideo = void 0;
const AbstractVideoMessage_1 = require("../AbstractVideoMessage");
/**
 * Represents a video message for the MMS channel.
 *
 * @group MMS
 */
class MMSVideo extends AbstractVideoMessage_1.AbstractVideoMessage {
    /**
     * Send an MMS video message.
     *
     * @param {MessageParamsVideo} params - The parameters for creating the video message.
     * @example
     * ```ts
     * import { MMSVideo } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new MMSVideo({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  video: {
     *    url: 'https://example.com/video.mp4',
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.channel = 'mms';
    }
}
exports.MMSVideo = MMSVideo;
