"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessengerImage = void 0;
const AbstractImageMessage_1 = require("../AbstractImageMessage");
/**
 * Represents an image message for the Messenger channel.
 *
 * This class extends the `AbstractImageMessage` class and implements the `MessengerImageParams` interface.
 * It is used for sending image messages on the Messenger channel.
 *
 * @group Messenger
 */
class MessengerImage extends AbstractImageMessage_1.AbstractImageMessage {
    /**
     * Send an image message using the Facebook Messenger channel.
     *
     * @param {MessengerImageParams} params - The parameters for the image message.
     * @example
     * ```ts
     * import { MessengerImage } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new MessengerImage({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  image: {
     *    url: 'https://example.com/image.jpg',
     *    caption: 'This is an image',
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.messenger = params.messenger;
        this.channel = 'messenger';
    }
}
exports.MessengerImage = MessengerImage;
