"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ViberFile = void 0;
const AbstractFileMessage_1 = require("../AbstractFileMessage");
/**
 * Represents a file message for the Viber Service channel.
 *
 * @group Viber
 */
class ViberFile extends AbstractFileMessage_1.AbstractFileMessage {
    /**
     * Send a file message using the Viber Service channel.
     *
     * @param {ViberFileParams} params - The parameters for the ViberFile message.
     * @example
     * ```ts
     * import { ViberFile } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new ViberFile({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  file: {
     *    url: 'https://my-host.com/my-file.pdf',
     *  },
     *  viberService: {
     *    action: {
     *      url: 'https://my-host.com/my-path',
     *      text: 'My button text',
     *    },
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.channel = 'viber_service';
    }
}
exports.ViberFile = ViberFile;
