"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WhatsAppFile = void 0;
const enums_1 = require("../../enums");
const AbstractFileMessage_1 = require("../AbstractFileMessage");
/**
 * Represents a file message for WhatsApp.
 *
 * @group WhatsApp
 */
class WhatsAppFile extends AbstractFileMessage_1.AbstractFileMessage {
    /**
     * Send a WhatsApp file message.
     *
     * @param {WhatsAppFileParams} params - The parameters for creating a WhatsApp file message.
     * @example
     * ```ts
     * import { WhatsAppFile } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new WhatsAppFile({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  file: {
     *    url: 'https://example.com/image.jpg',
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.channel = enums_1.Channels.WHATSAPP;
        if (params.context) {
            this.context = params.context;
        }
    }
}
exports.WhatsAppFile = WhatsAppFile;
