"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WhatsAppImage = void 0;
const AbstractImageMessage_1 = require("../AbstractImageMessage");
/**
 * Represents an image message for WhatsApp.
 *
 * @group WhatsApp
 */
class WhatsAppImage extends AbstractImageMessage_1.AbstractImageMessage {
    /**
     * Sends an image message to a WhatsApp user.
     *
     * @param {WhatsAppImageParams} params - The parameters for creating a WhatsApp image message.
     * @example
     * ```ts
     * import { WhatsAppImage } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new WhatsAppImage({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  image: {
     *    url: 'https://example.com/image.jpg',
     *    caption: 'This is an image message',
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.channel = 'whatsapp';
        if (params.context) {
            this.context = params.context;
        }
    }
}
exports.WhatsAppImage = WhatsAppImage;
