"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WhatsAppText = void 0;
const AbstractTextMessage_1 = require("../AbstractTextMessage");
/**
 * Represents a text message for WhatsApp.
 *
 * @group WhatsApp
 */
class WhatsAppText extends AbstractTextMessage_1.AbstractTextMessage {
    /**
     * Send a WhatsApp text message.
     *
     * @param {WhatsAppTextParams} params - The parameters for creating a WhatsApp text message.
     * @example
     * ```ts
     * import { WhatsAppText } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new WhatsAppText({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  text: 'Hello world',
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.channel = 'whatsapp';
        if (params.context) {
            this.context = params.context;
        }
    }
}
exports.WhatsAppText = WhatsAppText;
