"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WhatsAppVideo = void 0;
const AbstractVideoMessage_1 = require("../AbstractVideoMessage");
/**
 * Represents a video message for WhatsApp.
 *
 * @group WhatsApp
 */
class WhatsAppVideo extends AbstractVideoMessage_1.AbstractVideoMessage {
    /**
     * Sends a video message to a WhatsApp user.
     *
     * @param {WhatsAppVideoParams} params - The parameters for creating a WhatsApp video message.
     *
     * @example
     * ```ts
     * import { WhatsAppVideo } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new WhatsAppVideo({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  video: {
     *    url: 'https://example.com/video.mp4',
     *    caption: 'This is a video message',
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.channel = 'whatsapp';
        if (params.context) {
            this.context = params.context;
        }
    }
}
exports.WhatsAppVideo = WhatsAppVideo;
