export type TransformFunction = (key: string) => string;
/**
 * Transforms the keys of an object based on a provided transformation function.
 *
 * @param {TransformFunction} transformFn - The function to transform the object's keys.
 * @param {Record<string | number, unknown>} objectToTransform - The object whose keys are to be transformed.
 * @param {boolean} [deep=false] - Whether to deeply transform nested object keys.
 * @param {boolean} [preserve=false] - Whether to preserve the original object's keys.
 *
 * @return {Record<string | number, unknown>} A new object with transformed keys.
 */
export declare const transformObjectKeys: (transformFn: TransformFunction, objectToTransform: Record<string | number, unknown>, deep?: boolean, preserve?: boolean) => Record<string | number, unknown>;
/**
 * Transforms the keys of an object to camelCase.
 *
 * @param {Record<string | number, unknown>} objectToTransform - The object whose keys are to be transformed.
 * @param {boolean} [deep=false] - Whether to deeply transform nested object keys.
 * @param {boolean} [preserve=false] - Whether to preserve the original object's keys.
 * @return {Record<string | number, unknown>} A new object with camelCased keys.
 */
export declare const camelCaseObjectKeys: (objectToTransform: Record<string | number, unknown>, deep?: boolean | undefined, preserve?: boolean | undefined) => Record<string | number, unknown>;
/**
 * Transforms the keys of an object to snake_case.
 *
 * @param {Record<string | number, unknown>} objectToTransform - The object whose keys are to be transformed.
 * @param {boolean} [deep=false] - Whether to deeply transform nested object keys.
 * @param {boolean} [preserve=false] - Whether to preserve the original object's keys.
 * @return {Record<string | number, unknown>} A new object with snake_cased keys.
 */
export declare const snakeCaseObjectKeys: (objectToTransform: Record<string | number, unknown>, deep?: boolean | undefined, preserve?: boolean | undefined) => Record<string | number, unknown>;
/**
 * Transforms the keys of an object to kebab-case.
 *
 * @param {Record<string | number, unknown>} objectToTransform - The object whose keys are to be transformed.
 * @param {boolean} [deep=false] - Whether to deeply transform nested object keys.
 * @param {boolean} [preserve=false] - Whether to preserve the original object's keys.
 * @return {Record<string | number, unknown>} A new object with kebab-cased keys.
 */
export declare const kebabCaseObjectKeys: (objectToTransform: Record<string | number, unknown>, deep?: boolean | undefined, preserve?: boolean | undefined) => Record<string | number, unknown>;
/**
 * Omit keys from an object.
 *
 * @param {Array<string>} keys - The keys to omit.
 * @param {Record<string | number, unknown>} obj - The object from which to omit keys.
 *
 * @return {Record<string | number, unknown>} A new object with omitted keys.
 */
export declare const omit: (keys: Array<string>, obj: Record<string | number, unknown>) => Record<string | number, unknown>;
