import { SMSMessages, ErrorMessage, Message } from '../../types';
/**
 * Class representing a failure response when sending SMS messages.
 *
 * Extends the built-in Error class and provides methods for accessing and handling failed SMS messages.
 */
export declare class SMSFailure extends Error {
    /**
     * The response containing details about the SMS messages.
     */
    protected response: SMSMessages;
    /**
     * Creates an instance of SMSFailure.
     *
     * @param {string} message - The error message.
     * @param {SMSMessages} response - The response containing details about the SMS messages.
     */
    constructor(message: string, response: SMSMessages);
    /**
     * Retrieves an array of all messages in the response.
     *
     * @return {Array<ErrorMessage | Message>} An array of all messages in the response.
     */
    getMessages(): Array<ErrorMessage & Message>;
    /**
     * Retrieves an array of failed messages in the response.
     *
     * @return {Array<ErrorMessage>} An array of failed messages in the response.
     */
    getFailedMessages(): Array<ErrorMessage>;
    /**
     * Retrieves the original response containing details about the SMS messages.
     *
     * @return {SMSMessages} The original response containing details about the SMS messages.
     */
    getResponse(): SMSMessages;
    /**
     * Retrieves an array of successfully sent messages in the response.
     *
     * @return {Array<Message>} An array of successfully sent messages in the response.
     */
    getSuccessfulMessages(): Array<Message>;
}
