import { AuthenticationType, Client } from '@vonage/server-client';
import { Request, VerificationRequestParams } from './types';
/**
 * A class for interacting with the Vonage Verify API (Version 2).
 */
export declare class Verify2 extends Client {
    /**
     * The authentication type used for this client (JWT).
     */
    protected authType: AuthenticationType;
    /**
     * Creates a new verification request.
     *
     * @param {VerificationRequestParams} params - The parameters for the
     *  verification request.
     * @return {Request} A `Request` object containing the request ID.
     */
    newRequest(params: VerificationRequestParams): Promise<Request>;
    /**
     * Checks a verification code against a verification request.
     * @param {string} requestId - The ID of the verification request.
     * @param {string} code - The verification code to check.
     * @return {string} The status of the verification code check.
     */
    checkCode(requestId: string, code: string): Promise<string>;
    /**
     * Cancels a verification request.
     * @param {string} requestId - The ID of the verification request to cancel.
     * @return {boolean} `true` if the cancellation was successful.
     */
    cancel(requestId: string): Promise<boolean>;
}
