import { NotifyAction } from '../../types';
import { Serializable } from '../../ncco';
import { NCCOActions } from '../../enums';
/**
 * Represents a Notify action in an NCCO.
 */
export declare class Notify implements NotifyAction, Serializable {
    action: NCCOActions.NOTIFY;
    payload: {
        [key: string]: string;
    };
    eventUrl: string[];
    eventMethod?: string;
    /**
     * Creates a new Notify action.
     *
     * @param {Object} payload - The payload data to send with the notification.
     * @param {string} eventUrl - The URL where the notification events will be sent.
     * @param {string} [eventMethod] - The HTTP method for sending notification events (e.g., "POST").
     */
    constructor(payload: {
        [key: string]: string;
    }, eventUrl: string, eventMethod?: string);
    /**
     * Serialize the Notify action to an NCCO-compatible format.
     *
     * @return {NotifyAction} - The serialized Notify action.
     */
    serializeToNCCO(): NotifyAction;
}
